django-sitemetrics documentation
================================

http://github.com/idlesign/django-sitemetrics

*Reusable application for Django providing easy means to integrate site metrics counters into your sites*


Requirements
------------

1. Python 2.7+ or 3.3+
2. Django 1.4+
3. Django Sites contrib enabled (optional)
4. Django Admin contrib enabled (optional)
5. South (for automatic DB migrations)


Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart
    customization


Get involved into django-sitemetrics
------------------------------------

**Submit issues.** If you spotted something weird in application behavior or want to propose a feature you can do that at https://github.com/idlesign/django-sitemetrics/issues

**Write code.** If you are eager to participate in application development, fork it at https://github.com/idlesign/django-sitemetrics, write your code, whether it should be a bugfix or a feature implementation, and make a pull request right from the forked project page.

**Translate.** If want to translate the application into your native language use Transifex: https://www.transifex.com/projects/p/django-sitemetrics/.

**Spread the word.** If you have some tips and tricks or any other words in mind that you think might be of interest for the others — publish them.


Also
----

If the application is not what you want for site metrics, you might be interested in considering the other choices — https://www.djangopackages.com/grids/g/analytics/
